@@ -1,8 +1,10 @@
 #!/usr/bin/python3
 
+from .engine import screenshot_grabber as camera
 from .engine import event_handler as event_handler
 from .engine import interpreter as interpreter
 from .engine import translator as translator
+
 import glob
 import json
 import os
@@ -12,6 +14,8 @@ import shutil
 import threading
 import time
 import webbrowser
+import mss
+import multiprocessing as mp
 
 from jinja2 import Environment, FileSystemLoader
 from tkinter import *
@@ -32,7 +36,7 @@ class AppGui:
         self.formatted_output = None
         self.collector = event_handler.Collector("gui", 1)
         self.collector_report = {}
-        self.running_thread = None
+
         self.workdir = "."
         self.saved_status = "not saved"
         # Global choices are a place to hold the file name, format and path.
@@ -695,15 +699,6 @@ class AppGui:
 
 ## Record Screen Commands
 
-    def threaded(self):
-        """ Represents the thread to be started. """
-        self.collector.start()
-
-    def start_thread(self):
-        """ Start the thread. """
-        self.running_thread = threading.Thread(target=self.threaded, daemon=True)
-        self.running_thread.start()
-
     def start_recording(self):
         """ Start recording the events and deal with GUI events. """
         # Deal with UI stuff
@@ -724,21 +719,18 @@ class AppGui:
         self.clean_output = {}
 
         # Start the collector.
-        #if not self.running_thread:
-        self.start_thread()
-        #elif not self.running_thread.is_alive():
-        #    self.start_thread()
-        #    print(self.running_thread.native_id)
-        #else:
-        #    print(self.running_thread.native_id)
+        camera.do_grab()
+        self.collector.start()
 
     def stop_recording(self):
         """ Stop recording and deal with necessary stuff.  """
         # Stop the collector
         self.collector.stop()
+        camera.no_grab()
         # Store the raw output which is basically a collection of all events
         # returned from the collector.
         self.raw_output = self.collector.return_report()
+        # Deregister collector
         # Run the raw output through the interpreter to have cleaned report
         # created (supported events and meta events only).
         self.interpret = interpreter.Interpreter(self.raw_output, stop_key="gui")
@@ -753,8 +745,6 @@ class AppGui:
         self.update_locked_field(self.eprogress, "Recording stopped")
         self.update_locked_field(self.ertotal, len(self.raw_output.keys()))
         self.update_locked_field(self.ectotal, len(self.clean_output.keys()))
-        # Join the thread and let it stop.
-        self.running_thread.join()
         # Now make sure, the report is known as "full"
         self.choices['report'] = "full"
 
@@ -972,15 +962,25 @@ class AppGui:
         self.etimestamp.focus_set()
 
 # Main application
+
 def main():
+    q = mp.Queue()
+    p = mp.Process(target=camera.start, args=(q,))
+    p.daemon = True
+    p.start()
+
+    camera.QUEUE = q
+    camera.no_grab()
+
     appwin = Tk()
     appwin.title("AutoCoconut - a workflow tracking tool.")
     appwin.minsize(width=1024, height=550)
     appwin.resizable(False, False)
-    
+
     appgui = AppGui(appwin)
-    
+
     appwin.mainloop()
 
+
 if __name__ == "__main__":
     main()
