@@ -179,13 +179,17 @@ class Translator:
                 # Combination comes in the form of a list. We need to join it into string in order to show it
                 # in the formatted output.
                 combo = data["combined"]
-                # For openqa, the names must be replaced with openqa standards.
-                if combo and lang == 'openqa':
-                    combo = [x if x not in self.openqa_keys.keys() else self.openqa_keys[x] for x in combo]
-                    combo = "-".join(combo)
-                elif combo:
-                    combo = "-".join(combo)
-                data['combined'] = combo
+                # For openqa, the names must be replaced with openqa standards. But we will only do trick if the combo
+                # is still in the form of a list. 
+                # In CLI with only one pass, this is not a problem, but whenever this method ran again, it tend to
+                # change the format of this over and over again producing funny results.
+                if isinstance(combo, list):
+                    if combo and lang == 'openqa':
+                        combo = [x if x not in self.openqa_keys.keys() else self.openqa_keys[x] for x in combo]
+                        combo = "-".join(combo)
+                    elif combo:
+                        combo = "-".join(combo)
+                    data['combined'] = combo
                 # Mouse and keyboard events have different json information, so we will handle mouse and keyboard separately.
                 if 'mouse' in data['type']:
                     coordinates = data['coordinates']
